# John Larkin - Collegiate Tennis Career

## Overview
- **School:** Swarthmore College
- **Years:** 2013-2017
- **Position:** Singles #1-4, Doubles #2-3
- **Conference:** Centennial Conference
- **Doubles Partner:** Blake Oetting (primary)

## Awards & Honors

### 2016
- CoSIDA Academic All-District IV Men's At-Large First Team
- All-Conference First Team (Singles)
- ITA Scholar-Athlete
- Philadelphia Inquirer Academic All-Area
- Conference Player of the Week (5/2, 4/4)
- Centennial Conference Spring Academic Honor Roll

### 2015
- All-Conference First Team (Singles)
- Conference Player of the Week (4/6, 3/2)
- Centennial Conference Spring Academic Honor Roll

---

## 2016-2017 Season

### Singles

| Date | Opponent | Pos | Score | Result |
|------|----------|-----|-------|--------|
| Oct 1-3, 2016 | Johns Hopkins (Aaron Carey) | t-64 | 1-6, 3-6 | L |
| Feb 18, 2017 | #28 Chris. Newport (Justin Cerny) | 2 | 7-5, 6-3 | W |
| Feb 18, 2017 | #24 Whitman College (Petar Jivkov) | 2 | 5-7, 6-0, 2-6 | L |
| Mar 04, 2017 | #38 Washington and Lee (Will Bannister) | 2 | 7-5, 2-6, 1-6 | L |
| Mar 04, 2017 | #28 Sewanee (Andres Carro) | 2 | 7-6, 2-6, 3-6 | L |
| Mar 08, 2017 | #18 University of Redlands (Parker Wilson) | 2 | 6-3, 6-4 | W |
| Mar 9, 2017 | #6 Claremont-Mudd-Scripps (Daniel Morkovine) | 2 | 5-7, 0-6 | L |
| Mar 10, 2017 | #9 Pomona-Pitzer (Antony Bello) | 2 | 6-7 (4-7), 5-7 | L |
| Mar 11, 2017 | #7 Carnegie Mellon (Chaz Downing) | 2 | 0-6, 4-6 | L |
| Mar 26, 2017 | #38 Stevens (Kyle Henry) | 2 | 6-2, 6-1 | W |
| Mar 28, 2017 | Ursinus (Paul Vecchio) | 2 | 6-1, 6-1 | W |
| Apr 01, 2017 | Dickinson (Derek Chen) | 2 | 6-2, 6-1 | W |
| Apr 02, 2017 | #16 Mary Washington (Patrick Hughes) | 2 | 6-2, 6-4 | W |
| Apr 08, 2017 | Gettysburg (Kevin DeRosa) | 2 | 6-0, 6-1 | W |
| Apr 11, 2017 | Washington College (Jake Sandler) | 2 | 6-7 (5-7), 7-6 (7-5), 1-0 (10-6) | W |
| Apr 15, 2017 | #13 Amherst (Josh Marchalik) | 2 | 0-6, 0-6 | L |
| Apr 19, 2017 | Muhlenberg (David Woods) | 1 | 6-0, 6-2 | W |
| Apr 22, 2017 | Franklin & Marshall (Isaac Salas) | 2 | 6-1, 6-4 | W |
| Apr 25, 2017 | Haverford (Dais Nakayama) | 2 | 6-1, 6-0 | W |
| Apr 29, 2017 | #17 Johns Hopkins (Scott Thygesen) | 2 | 3-1, retired | W |
| May 6, 2017 | Haverford (Dais Nakayama) | 2 | 6-2, 6-1 | W |
| May 07, 2017 | #17 Johns Hopkins (Scott Thygesen) | 2 | 4-6, 6-1, 0-1, unfinished | - |

### Doubles (Partner: Blake Oetting)

| Date | Opponent | Pos | Score | Result |
|------|----------|-----|-------|--------|
| Oct 1-3, 2016 | Muhlenberg (A. Dagilis/D. Wood) | t-64 | 8-4 | W |
| Oct 1-3, 2016 | Carnegie Mellon (J. Chen/M. Seifert) | t-32 | 9-8 | W |
| Oct 1-3, 2016 | Christopher Newport (J. Cerny/D. Reed) | t-16 | 4-8 | L |
| Feb 18, 2017 | #28 Chris. Newport (M. Dodd/A. Fiva) | 3 | 7-8 (5-7) | L |
| Feb 18, 2017 | #24 Whitman College (T. Fennessy/G. Ho) | 3 | 8-5 | W |
| Mar 04, 2017 | #38 Washington and Lee (J. Krasner/M. Thomas) | 3 | 1-8 | L |
| Mar 04, 2017 | #28 Sewanee (J. Brewer/A. Davis) | 3 | 8-6 | W |
| Mar 08, 2017 | #18 University of Redlands (P. Wilson/T. Suchodolski) | 3 | 9-8 | W |
| Mar 9, 2017 | #6 Claremont-Mudd-Scripps (J. Berber/D. Park) | 3 | 8-6 | W |
| Mar 10, 2017 | #9 Pomona-Pitzer (S. Gearou/J. Gearou) | 3 | 4-8 | L |
| Mar 11, 2017 | #7 Carnegie Mellon (K. Zheng/M. Rozenvasser) | 3 | 4-8 | L |
| Mar 26, 2017 | #38 Stevens (W. Persson/D. Sarthak) | 3 | 6-8 | L |
| Mar 28, 2017 | Ursinus (H. Burke/C. DeFaber-Schumacher) | 3 | 8-2 | W |
| Apr 01, 2017 | Dickinson (L. Burstein/Q. Hua) | 3 | 8-0 | W |
| Apr 02, 2017 | #16 Mary Washington (J. Brown/P. Hughes) | 3 | 8-6 | W |
| Apr 08, 2017 | Gettysburg (K. DeRosa/D. McVeigh) | 3 | 8-2 | W |
| Apr 11, 2017 | Washington College (Z. Novick/J. Panepinto) | 3 | 8-6 | W |
| Apr 15, 2017 | #13 Amherst (A. Arnaboldi/N. Kaplan) | 3 | 4-8 | L |
| Apr 19, 2017 | Muhlenberg (S. Shoemaker/J. Yandle) | 2 | 8-0 | W |
| Apr 22, 2017 | Franklin & Marshall (A. Pace/I. Salas) | 3 | 6-8 | L |
| Apr 25, 2017 | Haverford (E. Phelps/N. Sweeney) | 3 | 8-4 | W |
| Apr 29, 2017 | #17 Johns Hopkins (D. Perez/S. Thygesen) | 3 | 6-8 | L |
| May 6, 2017 | Haverford (E. Phelps/N. Sweeney) | 3 | 8-3 | W |
| May 07, 2017 | #17 Johns Hopkins (D. Perez/S. Thygesen) | 3 | 6-8 | L |

---

## 2015-2016 Season

### Singles

| Date | Opponent | Pos | Score | Result |
|------|----------|-----|-------|--------|
| Oct 3-5, 2015 | University of Mary Washington (Matt Miles) | t-64 | 3-6, 6-1, 6-2 | W |
| Oct 3-5, 2015 | Franklin & Marshall (Zack Levin) | t-32 | 6-1, 6-4 | W |
| Oct 3-5, 2015 | Johns Hopkins (David Perez) | t-16 | 4-6, 1-6 | L |
| Feb 24, 2016 | #25 Stevens (Danny Polk) | 2 | 6-3, 6-0 | W |
| Feb 27, 2016 | New York University (Samuel Khoshbin) | 2 | 6-0, 6-1 | W |
| Mar 05, 2016 | Cal Lutheran Univ. (Dara Kashani) | 2 | 6-2, 6-4 | W |
| Mar 05, 2016 | Lewis & Clark (Raed Attia) | 2 | 6-2, 6-3 | W |
| Mar 06, 2016 | #18 Whitman College (Phillip Locklear) | 2 | 7-5, 1-6, 1-0 (11-9) | W |
| Mar 08, 2016 | Portland State (Ethan Lopez) | 2 | 5-7, 3-6 | L |
| Mar 10, 2016 | Seattle University (John Stormans) | 2 | 6-4, 6-1 | W |
| Mar 18, 2016 | #23 Bates (Chris Ellis) | 2 | 1-6, 6-3, 2-6 | L |
| Mar 23, 2016 | Ursinus (Tyler Arsenault) | 2 | 6-3, 6-0 | W |
| Mar 26, 2016 | #20 Washington and Lee (Will Bannister) | 2 | 1-6, 3-6 | L |
| Apr 2, 2016 | #21 Johns Hopkins (Jeremy Dubin) | 2 | 7-5, 6-3 | W |
| Apr 03, 2016 | #27 University of Mary Washington (Eric Hurwitz) | 2 | 6-1, 6-4 | W |
| Apr 6, 2016 | Muhlenberg (Derrick Eng) | 2 | 6-0, 6-0 | W |
| Apr 08, 2016 | Gettysburg (C. Deschapelles) | 2 | 6-4, 6-1 | W |
| Apr 16, 2016 | #29 Franklin & Marshall (Zack Levin) | 2 | 6-0, 6-0 | W |
| Apr 22, 2016 | Dickinson (Steven Kaplan) | 2 | 6-0, 6-1 | W |
| Apr 26, 2016 | Washington College (Jake Sandler) | 2 | 6-3, 6-2 | W |
| Apr 30, 2016 | Haverford (Josh Moskovitz) | 2 | 6-2, 6-3 | W |
| May 07, 2016 | Franklin & Marshall (Zack Levin) | 2 | 6-1, 6-1 | W |
| May 08, 2016 | #26 Johns Hopkins (Jeremy Dubin) | 2 | 5-7, 1-6 | L |

### Doubles (Partner: Blake Oetting)

| Date | Opponent | Pos | Score | Result |
|------|----------|-----|-------|--------|
| Feb 24, 2016 | #25 Stevens (C. Drake/K. Cenderelli) | 3 | 8-5 | W |
| Feb 27, 2016 | New York University (S. Khoshbin/S. Kundur) | 3 | 8-2 | W |
| Mar 05, 2016 | Lewis & Clark (K. Ross/M. Brewer) | 3 | 8-3 | W |
| Mar 06, 2016 | #18 Whitman College (R. Carter/A. Rapoport) | 3 | 4-8 | L |
| Mar 18, 2016 | #23 Bates (J. Leiner/J. Quijano) | 3 | 8-5 | W |
| Mar 23, 2016 | Ursinus (C. Phan/P. Shields) | 3 | 8-2 | W |
| Mar 26, 2016 | #20 Washington and Lee (M. Lukas/J. Gillette) | 3 | 8-3 | W |
| Apr 2, 2016 | #21 Johns Hopkins (J. Kang/S. Thygesen) | 3 | 8-5 | W |
| Apr 03, 2016 | McDaniel (C. Glocker/A. Kendrick) | 2 | 8-1 | W |
| Apr 03, 2016 | #27 University of Mary Washington (P. Hughes/D. Hagino) | 3 | 8-2 | W |
| Apr 6, 2016 | Muhlenberg (J. Yandle/S. Shoemaker) | 3 | 8-2 | W |
| Apr 08, 2016 | Gettysburg (K. Maier/W. Vehslage) | 3 | 8-3 | W |
| Apr 16, 2016 | #29 Franklin & Marshall (Z. Levin/I. Salas) | 3 | 8-5 | W |
| Apr 22, 2016 | Dickinson (S. Loring/S. Diniz) | 3 | 8-4 | W |
| Apr 26, 2016 | Washington College (J. Panepinto/M. Katz) | 3 | 8-3 | W |
| Apr 30, 2016 | Haverford (C. Mayer/N. Sweeney) | 3 | 8-2 | W |
| May 07, 2016 | Franklin & Marshall (Z. Levin/I. Salas) | 3 | 8-3 | W |
| May 08, 2016 | #26 Johns Hopkins (D. Perez/S. Thygesen) | 3 | 8-5 | W |

---

## 2014-2015 Season

### Singles

| Date | Opponent | Pos | Score | Result |
|------|----------|-----|-------|--------|
| Feb 25, 2015 | Delaware (Mike Furr) | 1 | 6-2, 6-1 | W |
| Feb 28, 2015 | #30 New York University (Sidd Thangirala) | 1 | 3-6, 7-5, 6-4 | W |
| March 3, 2015 | #31 Stevens Institute (Matthew Heinrich) | 1 | 6-3, 3-6, 2-6 | L |
| March 9, 2015 | #37 Washington and Lee (Christopher Hu) | 1 | retired | W |
| March 13, 2015 | #19 Mary Washington (Tyler Carey) | 1 | 0-6, 2-6 | L |
| March 17, 2015 | #2 Claremont-Mudd-Scripps (Warren Wood) | 1 | 5-7, 2-6 | L |
| March 19, 2015 | Ursinus (Caleb Kramer) | 1 | 6-3, 6-0 | W |
| March 21, 2015 | #25 DePauw University (Chris Bertolini) | 1 | 7-6 (11-9), 6-1 | W |
| Mar 22, 2015 | #8 Kenyon College (Wade Heerboth) | 1 | 6-4, 4-6, 1-6 | L |
| March 31, 2015 | Muhlenberg (Daniel Lakhman) | 1 | 7-5, 6-4 | W |
| Apr 04, 2015 | Gettysburg College (Dave Musser) | 1 | 6-2, 6-0 | W |
| Apr. 11, 2015 | Franklin & Marshall (Doug Kaplan) | 1 | 6-3, 6-3 | W |
| Apr 15, 2015 | #11 Johns Hopkins (Mike Buxbaum) | 1 | 1-6, 1-6 | L |
| Apr 18, 2015 | Dickinson (Steven Kaplan) | 1 | 6-0, 6-1 | W |
| Apr. 22, 2015 | Washington College (Vishnu Rajes) | 1 | 6-0, 6-1 | W |
| Apr 25, 2015 | Haverford (Luis Acaba) | 1 | 6-3, 6-2 | W |
| May 2, 2015 | Franklin & Marshall (Doug Kaplan) | 1 | 6-4, 0-3, unfinished | - |
| May 03, 2015 | #17 Johns Hopkins (Mike Buxbaum) | 1 | 3-6, 2-2, unfinished | - |

### Doubles (Partner: Blake Oetting)

| Date | Opponent | Pos | Score | Result |
|------|----------|-----|-------|--------|
| Feb 25, 2015 | Delaware (M. Furr/A. Sweet) | 3 | 9-8 | W |
| Feb 28, 2015 | #30 New York University (D. Zumwalt/S. Khoshbin) | 3 | 8-4 | W |
| March 3, 2015 | #31 Stevens Institute (K. Henry/A. Perich) | 3 | 8-1 | W |
| March 9, 2015 | #37 Washington and Lee (W. Bannister/J. Krasner) | 2 | 4-8 | L |
| March 13, 2015 | #19 Mary Washington (D. Lunding-Johansson/A. Curtis) | 3 | 6-8 | L |
| March 17, 2015 | #2 Claremont-Mudd-Scripps (N. Marino/G. Hull) | 3 | 4-8 | L |
| March 19, 2015 | Ursinus (H. Burke/D. Lynch) | 2 | 8-2 | W |
| March 21, 2015 | #25 DePauw University (C. Bertolini/D. Rodefeld) | 2 | 7-9 | L |
| Mar 22, 2015 | #8 Kenyon College (C. Haas/W. Heerboth) | 2 | 2-8 | L |
| March 31, 2015 | Muhlenberg (D. Woods/J. Greene) | 3 | 8-1 | W |
| Apr 04, 2015 | Gettysburg College (K. Roveda/A. Egglin) | 3 | 8-1 | W |
| Apr. 11, 2015 | Franklin & Marshall (W. Samuels/E. Drapeau) | 3 | 8-1 | W |
| Apr 18, 2015 | Dickinson (J. Kaseff/E. Davis) | 3 | 8-3 | W |
| Apr. 22, 2015 | Washington College (Z. Novick/J. Panepinto) | 3 | 8-1 | W |
| Apr 25, 2015 | Haverford (E. Phelps/B. Soloway) | 3 | 8-3 | W |
| May 2, 2015 | Franklin & Marshall (J. Rothman/H. Pataudi) | 3 | 8-1 | W |
| May 03, 2015 | #17 Johns Hopkins (T. Brown/E. Lim) | 3 | 0-8 | L |

---

## 2013-2014 Season

### Singles

| Date | Opponent | Pos | Score | Result |
|------|----------|-----|-------|--------|
| Sep 28-30, 2013 | Mary Washington (Andrew Curtis) | t-16 | 6-4, 6-3 | W |
| Sep 28-30, 2013 | Johns Hopkins (Noah Joachim) | t-Q | 6-4, 3-6, 14-12 | W |
| Sep 28-30, 2013 | Kunai Wadwani | t-SF | 6-3, 6-4 | W |
| Sep 28-30, 2013 | Johns Hopkins (Jeffrey McKenzie) | t-F | 6-2, 4-6, 1-10 | L |
| Feb 22, 2014 | Delaware (Alex Sweet) | 4 | 6-2, 6-0 | W |
| Mar 01, 2014 | Stevens (Michael Feldman) | 4 | 6-2, 3-6, 2-6 | L |
| Mar 12, 2014 | #26 Skidmore (Gabe Steerman) | 4 | 4-6, 6-7 | L |
| Mar 14, 2014 | #3 Claremont-Mudd-Scripps (Daniel Morkovine) | 4 | 6-2, 1-6, 0-10 | L |
| Mar 14, 2014 | #16 Pomona-Pitzer (Jonathan Kim) | 4 | 3-6, 2-6 | L |
| Mar 15, 2014 | #18 Gustavus Adolphus (Joey McGibbon) | 4 | 7-5, 2-6, 4-6 | L |
| Mar 20, 2014 | Ursinus College (Tyler Arsenault) | 3 | 6-1, 6-0 | W |
| Mar 22, 2014 | #9 Kenyon College (Tim Rosensteel) | 4 | 6-3, 6-3 | W |
| Mar 26, 2014 | Kalamazoo College (Mike Korn) | 3 | 3-6, 6-3, 6-2 | W |
| Apr 02, 2014 | Muhlenberg (Eric Chavis) | 4 | 6-1, 6-0 | W |
| Apr 05, 2014 | #17 University of Mary Washington (Evan Charles) | 4 | 7-5, 6-2 | W |
| Apr 09, 2014 | McDaniel (Seth McFall) | 2 | 6-2, 6-2 | W |
| Apr 12, 2014 | Franklin & Marshall (Nolan Bacchieri) | 3 | 6-3, 6-0 | W |
| Apr 18, 2014 | #6 Johns Hopkins (Jeremy Dubin) | 3 | 6-3, 6-2 | W |
| Apr 19, 2014 | Dickinson (Erik Dinardo) | 3 | 6-1, 6-0 | W |
| Apr 22, 2014 | #20 Washington College (Joel Novick) | 3 | 6-0, 6-2 | W |
| Apr 26, 2014 | #14 Haverford College (Matt Romei) | 3 | 6-3, 7-6 | W |
| May 03, 2014 | #11 Haverford College (Matt Romei) | 3 | 6-1, 2-0, unfinished | - |
| May 04, 2014 | #3 Johns Hopkins (Tanner Brown) | 3 | 5-7, 2-6 | L |

### Doubles (Partner: James Chen / Irving Stone)

| Date | Opponent | Partner | Pos | Score | Result |
|------|----------|---------|-----|-------|--------|
| Sep 28-30, 2013 | Elizabethtown (M. Cannon/C. Turula) | James Chen | t-R2 | 8-5 | W |
| Sep 28-30, 2013 | Christopher Newport (S. Boslet/S. Thompson) | James Chen | t-R3 | 2-8 | L |
| Sep 28-30, 2013 | Christopher Newport (S. Boslet/S. Thompson) | James Chen | t-32 | 6-8 | L |
| Apr 22, 2014 | #20 Washington College (J. Novick/Z. Novick) | Irving Stone | 3 | 8-2 | W |
